@@ -156,6 +156,26 @@ mod tests {
           // autocorrect-enable
 
           const c = "这是string第3行";
+          // jsx for test inline script
+          return <div className="react-app">
+            <>
+              <ul show_last={show_last}>
+                <li>第1项目<strong>li标签</strong></li>
+                <li>第2项目<strong>li标签</strong></li>
+                { show_last && (
+                  <li>
+                    <div>第3项目<strong>li标签</strong></div>
+                    <List renderItem={(item) => (
+                      <Item className="list-item">
+                        <span>nested项</span>
+                        <span>{item}</span>
+                      </Item>
+                    )} />
+                  </li>
+                )}
+              </ul>
+            </>
+          </div>
         }
         "###};
 
@@ -169,7 +189,14 @@ mod tests {
             { "l": 7, "c": 17, "new": "\"这是 single line 单行注释\"", "old": "\"这是single line单行注释\"", "severity": 1 },
             { "l": 8, "c": 15, "new": "`这是 string 第 1 行", "old": "`这是string第1行", "severity": 1 },
             { "l": 9, "c": 3, "new": "这是 string 第 2 行", "old": "这是string第2行", "severity": 1 },
-            { "l": 17, "c": 13, "new": "\"这是 string 第 3 行\"", "old": "\"这是string第3行\"", "severity": 1 }
+            { "l": 17, "c": 13, "new": "\"这是 string 第 3 行\"", "old": "\"这是string第3行\"", "severity": 1 },
+            { "l": 22,   "c": 13,   "new": "第 1 项目",   "old": "第1项目",   "severity": 1 },
+            { "l": 22,   "c": 25,   "new": "li 标签",   "old": "li标签",   "severity": 1 },
+            { "l": 23,   "c": 13,   "new": "第 2 项目",   "old": "第2项目",   "severity": 1 },
+            { "l": 23,   "c": 25,   "new": "li 标签",   "old": "li标签",   "severity": 1 }, 
+            { "l": 26,   "c": 18,   "new": "第 3 项目",   "old": "第3项目",   "severity": 1 }, 
+            { "l": 26,   "c": 30,   "new": "li 标签",   "old": "li标签",   "severity": 1 }, 
+            { "l": 29,   "c": 23,   "new": "nested 项",   "old": "nested项",   "severity": 1 }
           ],
           "error": ""
         }
@@ -177,7 +204,7 @@ mod tests {
 
         let lint_result = lint_for(example, "test.js").to_json();
 
-        assert_json_eq!(expect, lint_result);
-        assert_json_eq!(expect, lint_for(example, "test.js").to_json_pretty());
+        assert_json_eq!(expect, &lint_result);
+        assert_json_eq!(expect, &lint_for(example, "test.js").to_json_pretty());
     }
 }
